@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: config.h 9153 2008-12-03 18:09:09Z doligez $ */
+/* $Id: config.h 10787 2010-11-10 15:47:34Z doligez $ */
 
 #ifndef CAML_CONFIG_H
 #define CAML_CONFIG_H
@@ -24,13 +24,14 @@
 #define ARCH_INT64_TYPE long long
 #define ARCH_UINT64_TYPE unsigned long long
 #define ARCH_INT64_PRINTF_FORMAT "ll"
-#define ARCH_BIG_ENDIAN
-#undef ARCH_ALIGN_DOUBLE
-#undef ARCH_ALIGN_INT64
+#undef ARCH_BIG_ENDIAN
+#define ARCH_ALIGN_DOUBLE
+#define ARCH_ALIGN_INT64
 #undef NONSTANDARD_DIV_MOD
 #define OCAML_OS_TYPE "Unix"
 #define OCAML_STDLIB_DIR "/usr/local/lib/ocaml"
 #define POSIX_SIGNALS
+#define HAS_EXPM1_LOG1P
 #define HAS_GETRUSAGE
 #define HAS_TIMES
 #define HAS_TERMCAP
@@ -186,7 +187,7 @@ typedef struct { uint32 l, h; } uint64, int64;
 #define Minor_heap_max (1 << 28)
 
 /* Default size of the minor zone. (words)  */
-#define Minor_heap_def 32768
+#define Minor_heap_def 262144
 
 
 /* Minimum size increment when growing the heap (words).
